from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a10_library_version = QzssDcrDefinition(
    {
        0: '#1',
#        1: '#2',
#        2: '#3',
#        3: '#4',
#        4: '#5',
#        5: '#6',
#        6: '#7',
#        7: '#8',
    },
    undefined='Unsupported Library Version (Code: %d)'
)
