from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a6_hazard_onset_week = QzssDcrDefinition(
    {
        0: 'Current',
        1: 'Next',
    },
    undefined='Undefined Hazard Onset (Code: %d)'
)
