from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a17_main_subject_for_specific_settings = QzssDcrDefinition(
    {
        0: 'B1 - Improved Resolution of Main Ellipse',
        1: 'B2 - Position of the Centre of the Hazard',
        2: 'B3 - Secondary Ellipse Definition',
        3: 'B4 - Quantitative and detailed information about the Hazard',
    },
    undefined='Unsupported Library Version (Code: %d)'
)
