from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcr_jma_volcanic_warning_code = QzssDcrDefinition(
    {
        11: "レベル1(活火山であることに留意)",
        12: "レベル2(火口周辺規制)",
        13: "レベル3(入山規制)",
        14: "レベル4(高齢者等避難)",
        15: "レベル5(避難)",
        21: "活火山であることに留意",
        22: "火口周辺危険",
        23: "入山危険",
        24: "山麓厳重警戒",
        25: "居住地域厳重警戒",
        35: "活火山であることに留意(海底火山)",
        36: "周辺海域警戒",
        52: "噴火",
        62: "噴火したもよう",
        127: "その他の防災気象情報要素",
        # "NNN*": "防災気象情報要素(コード番号：NNN)",
    },
    undefined="防災気象情報要素(コード番号：%d)"
)
