from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a9_selection_of_library = QzssDcrDefinition(
    {
        0: 'International library',
        1: 'Country/region guidance library',
    },
    undefined='Undefined Library (Code: %d)'
)
