from .qzss_dcr_definition import QzssDcrDefinition


qzss_dcx_camf_a4_hazard_category = QzssDcrDefinition(
    {
        1: "CBRNE",
        2: "CBRNE",
        3: "CBRNE",
        4: "CBRNE",
        5: "CBRNE",
        6: "CBRNE",
        7: "CBRNE",
        8: "CBRNE",
        9: "CBRNE",
        10: "CBRNE",
        11: "CBRNE",
        12: "CBRNE",
        13: "CBRNE",
        14: "ENVIRONMENT",
        15: "ENVIRONMENT",
        16: "ENVIRONMENT",
        17: "ENVIRONMENT",
        18: "ENVIRONMENT",
        19: "ENVIRONMENT",
        20: "ENVIRONMENT",
        21: "ENVIRONMENT",
        22: "ENVIRONMENT",
        23: "ENVIRONMENT",
        24: "FIRE",
        25: "FIRE",
        26: "FIRE",
        27: "FIRE",
        28: "FIRE",
        29: "FIRE",
        30: "FIRE",
        31: "FIRE",
        32: "GEO",
        33: "GEO",
        34: "GEO",
        35: "GEO",
        36: "GEO",
        37: "GEO",
        38: "GEO",
        39: "GEO",
        40: "GEO",
        41: "GEO",
        42: "GEO",
        43: "GEO",
        44: "GEO",
        45: "GEO",
        46: "GEO",
        47: "GEO",
        48: "HEALTH",
        49: "HEALTH",
        50: "HEALTH",
        51: "HEALTH",
        52: "HEALTH",
        53: "HEALTH",
        54: "INFRASTRUCTURE",
        55: "INFRASTRUCTURE",
        56: "INFRASTRUCTURE",
        57: "INFRASTRUCTURE",
        58: "INFRASTRUCTURE",
        59: "INFRASTRUCTURE",
        60: "INFRASTRUCTURE",
        61: "MET",
        62: "MET",
        63: "MET",
        64: "MET",
        65: "MET",
        66: "MET",
        67: "MET",
        68: "MET",
        69: "MET",
        70: "MET",
        71: "MET",
        72: "MET",
        73: "MET",
        74: "MET",
        75: "MET",
        76: "MET",
        77: "MET",
        78: "MET",
        79: "MET",
        80: "MET",
        81: "MET",
        82: "MET",
        83: "RESCUE",
        84: "RESCUE",
        85: "RESCUE",
        86: "RESCUE",
        87: "RESCUE",
        88: "SAFETY",
        89: "SAFETY",
        90: "SAFETY",
        91: "SAFETY",
        92: "SAFETY",
        93: "SAFETY",
        94: "SAFETY",
        95: "SAFETY",
        96: "SAFETY",
        97: "SAFETY",
        98: "SECURITY",
        99: "SECURITY",
        100: "SECURITY",
        101: "SECURITY",
        102: "SECURITY",
        103: "SECURITY",
        104: "TRANSPORT",
        105: "TRANSPORT",
        106: "TRANSPORT",
        107: "TRANSPORT",
        108: "TRANSPORT",
        109: "TRANSPORT",
        110: "TRANSPORT",
        111: "TRANSPORT",
        112: "TRANSPORT",
        113: "OTHER",
    },
    undefined="UNDEFINED (Code: %d)"
)


qzss_dcx_camf_a4_hazard_type = QzssDcrDefinition(
    {
        1: "Air strike",
        2: "Attack on IT systems",
        3: "Attack with nuclear weapons",
        4: "Biological hazard",
        5: "Chemical hazard",
        6: "Explosive hazard",
        7: "Meteorite impact",
        8: "Missile attack",
        9: "Nuclear hazard",
        10: "Nuclear power station accident",
        11: "Radiological hazard",
        12: "Satellite/space re-entry debris",
        13: "Siren test",
        14: "Acid rain",
        15: "Air pollution",
        16: "Contaminated drinking water",
        17: "Gas leak",
        18: "Marine pollution",
        19: "Noise pollution",
        20: "Plague of insects",
        21: "River pollution",
        22: "Suspended dust",
        23: "UV radiation",
        24: "Conflagration",
        25: "Fire brigade deployment",
        26: "Fire gases",
        27: "Forest fire",
        28: "Fumes",
        29: "Odour nuisance",
        30: "Risk of fire",
        31: "Structure fire / Industrial fire",
        32: "Ash fall",
        33: "Avalanche risk",
        34: "Crack in the ground / sinkhole",
        35: "Debris flow",
        36: "Earthquake",
        37: "Geomagnetic or solar storm",
        38: "Glacial ice avalanche",
        39: "Landslide",
        40: "Lava flow",
        41: "Pyroclastic flow",
        42: "Snowdrifts",
        43: "Tidal wave",
        44: "Tsunami",
        45: "Volcanic mud flow",
        46: "Volcano eruption",
        47: "Wind / wave / storm surge",
        48: "Epizootic",
        49: "Food safety alert",
        50: "Health hazard",
        51: "Pandemic",
        52: "Pest infestation",
        53: "Risk of infection",
        54: "Building collapse",
        55: "Emergency number outage",
        56: "Gas supply outage",
        57: "Outage of IT systems",
        58: "Power outage",
        59: "Raw sewage",
        60: "Telephone line outage",
        61: "Black Ice",
        62: "Coastal flooding",
        63: "Cold wave",
        64: "Derecho",
        65: "Drought",
        66: "Dust storm",
        67: "Floating ice / icebergs",
        68: "Flood",
        69: "Fog",
        70: "Hail",
        71: "Heat wave",
        72: "Lightning",
        73: "Pollens",
        74: "Rainfall",
        75: "Snow storm / blizzard",
        76: "Snowfall",
        77: "Storm or thunderstorm",
        78: "Thawing",
        79: "Tornado",
        80: "Tropical cyclone (hurricane)",
        81: "Wind chill / frost",
        82: "Tropical cyclone (typhoon)",
        83: "Dam failure or bursting of a dam",
        84: "Dike failure or bursting of a dike",
        85: "Explosive ordnance disposal",
        86: "Factory accident",
        87: "Mine hazard",
        88: "Bomb / ammunition discovery",
        89: "Demonstration",
        90: "Hazardous material accident",
        91: "Life Threatening situation",
        92: "Major event",
        93: "Missing person / abduction",
        94: "Risk of explosion",
        95: "Safety warning",
        96: "Undefined flying object",
        97: "Unidentified animal",
        98: "Chemical attack",
        99: "Guerrilla attack",
        100: "Hijack",
        101: "Shooting or danger due to weapons",
        102: "Special forces attack",
        103: "Terrorism",
        104: "Aircraft crash",
        105: "Bridge collapse",
        106: "Dangerous goods accident",
        107: "Inland waterway transport accident",
        108: "Nautical disaster / Maritime / Marine Security",
        109: "Oil spill",
        110: "Road traffic incident",
        111: "Train/rail accident",
        112: "Tunnel accident",
        113: "Test alert",
    },
    undefined= "Undefined hazard type (Code: %d)",
)


qzss_dcx_camf_a4_hazard_definition = QzssDcrDefinition(
    {
        1: "Attack performed by an aircraft, usually of military type, either by bombing (or similar), firing guns or missiles.",
        2: "Intentional attempt to expose, alter, disable, destroy, steal or gain unauthorized access to or make unauthorised use of IT equipment.",
        3: "From www.dhs.gov 'Attack performed with a device producing a nuclear explosion.",
        4: "Presence of hazardous biological materials that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        5: "Presence of hazardous chemical materials that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        6: "Presence of hazardous explosive materials that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        7: "Meteorite entering from space into the earth atmosphere.",
        8: "Missile launch.",
        9: "Presence of hazardous nuclear materials that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        10: "Accident occurring at an installation where power is generated by a nuclear reactor.",
        11: "Presence of hazardous radioactive materials that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        12: "Satellite or parts of a satellite or launcher or space vehicle entering or re-entering from space into the earth atmosphere.",
        13: "Test of a warning device emitting a loud noise.",
        14: "Rain containing dissolved acidifying compounds, resulting from chemical pollution of the atmosphere by sulphur and nitrogen compounds. When deposited, these increase the acidity of the soil and water causing agricultural and ecological damage.",
        15: "Precise threshold is according to each local standard.",
        16: "Drinking water containing contaminants (germs and/or chemicals) above the quality standard. Precise threshold according to each local standard.",
        17: "Uncontrolled release of natural gas or gaseous product in the environment.",
        18: "Marine pollution occurs when substances used or spread by humans, such as industrial, agricultural and residential waste, particles, noise, excess carbon dioxide or invasive organisms enter the ocean and cause harmful effects there. Precise threshold is according to each local standard.",
        19: "Disturbing or unwanted noise that may present a potential risk to the health of humans, animals and wildlife.",
        20: "Infestation of insects or pervasive influx and development of insects or parasites affecting humans, animals, crops and materials.",
        21: "Contamination of water in rivers, usually as a result of human activities, in such a manner that negatively affects its legitimate uses.",
        22: "More general, particulates are microscopic solid particles suspended in the air. The source of the particulate matter can be natural or anthropogenic having adverse effect on human health. The IARC and WHO designate airborne particulates as a Group 1 carcinogen. Particulates are the most harmful form of air pollution due to their ability to penetrate deep into the lungs, blood streams and brain, causing health problems including heart attacks, respiratory disease, and premature death.",
        23: "Precise threshold is according to each local standard.",
        24: "A large and destructive fire that threatens human life, health, and/or property.",
        25: "Operation of firefighters in response to a fire or other emergency report. Note: Definition may vary, depending on the responsibility of the fire brigade in each country.",
        26: "Potentially dangerous gases emitted from a fire.",
        27: "A type of wildfire in a wooded area.",
        28: "An often-noxious suspension of particles in the air.",
        29: "Prolonged and offensive smell leading to the impairment of human well-being over a certain period of time at regular or irregular intervals.",
        30: "Increased likelihood of accidental fire.",
        31: "Fire affecting the structural parts of a building or a fire affecting an industrial site.",
        32: "Fine (less than 4 mm in diameter) unconsolidated volcanic debris blown into the atmosphere during an eruption; can remain airborne for long periods of time and travel considerable distance from the source.",
        33: "A large mass of loosened earth material, snow, or ice that slides, flows or falls rapidly down a mountainside under the force of gravity. Snow Avalanche: Rapid downslope movement of a mix of snow and ice. Debris Avalanche: The sudden and very rapid downslope movement of unsorted mass of rock and soil. There are two general types of debris avalanches - a cold debris avalanche usually results from an unstable slope suddenly collapsing whereas a hot debris avalanche results from volcanic activity leading to slope instability and collapse.",
        34: "Collapse of the land surface due to the dissolving of the subsurface rocks such as limestone or carbonate rock by water.",
        35: "Types of landslides that occur when heavy rain or rapid snow/ice melt send large amounts of vegetation, mud, or rock downslope by gravitational forces. Includes mud flow, rock fall.",
        36: "Sudden movement of a block of the Earth’s crust along a geological fault and associated ground shaking.",
        37: "A type of extra-terrestrial hazard caused by solar wind shockwaves that temporarily disturb the Earth’s magnetosphere. Geomagnetic storms can disrupt power grids, spacecraft operations, and satellite communications.",
        38: "Ice calving at end of a glacier.",
        39: "Independent of the presence of water, mass movement may also be triggered by earthquakes.",
        40: "The ejected magma that moves as a liquid mass downslope from a volcano during an eruption.",
        41: "Extremely hot gases, ash, and other materials of more than 1,000 ˚C that rapidly flow down the flank of a volcano (more than 700 km/h) during an eruption.",
        42: "Mass of snow heaped up by the wind and deposited along an obstruction or an irregularity of the terrain.",
        43: "Shallow water wave caused by the gravitational interactions between the Sun, Moon, and Earth. (from USGS)",
        44: "A series of waves (with long wavelengths when traveling across the deep ocean) that are generated by a displacement of massive amounts of water through underwater earthquakes, volcanic eruptions or landslides. Tsunami waves travel at very high speed across the ocean but as they begin to reach shallow water they slow down and the wave grows steeper.",
        45: "(Also known as Lahar) A mud flow resulting from a volcanic event. Hot or cold mixture of earthen material flowing on the slope of a volcano either during or between volcanic eruptions.",
        46: "A type of volcanic event near an opening/vent in the Earth’s surface including volcanic eruptions of lava, ash, hot vapour, gas, and pyroclastic material.",
        47: "An abnormal rise in sea level generated by a tropical cyclone or other intense storms.",
        48: "An epidemic outbreak of disease in an animal population, often with the implication that it may extend to humans.",
        49: "Presence of unsafe food containing harmful bacteria, viruses, parasites or chemical substances that present a risk to the health of humans, animals, plants or the environment.",
        50: "Potential source of danger for individual's health.",
        51: "An epidemic of an infectious disease that has spread across a large region, for instance multiple continents or worldwide, affecting a substantial number of people. A widespread endemic disease with a stable number of infected people is not a pandemic. Widespread endemic diseases with a stable number of infected people such as recurrences of seasonal influenza are generally excluded as they occur simultaneously in large regions of the globe rather than being spread worldwide.",
        52: "(from GEMET )1) The occurrence of one or more pest species in an area or location where their numbers and impact are currently or potentially at intolerable levels. 2) A sudden increase in destructiveness or population numbers of a pest species in a given area.",
        53: "Present of infectious agent(s) that present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        54: "Sudden failure of the building structure resulting in its partial or total destruction.",
        55: "Interruption or failure of emergency number service.",
        56: "Interruption or failure of gas supply service.",
        57: "Interruption or failure of IT systems services.",
        58: "Interruption or failure of electricity distribution service.",
        59: "Release in the environment of untreated wastewater.",
        60: "Interruption or failure of telephone service.",
        61: "WMO definition: (1) Thin, new ice on freshwater or saltwater, appearing dark in colour because of its transparency, which is a result of its columnar grain structure. On lakes, black ice is commonly overlain by white ice formed from refrozen snow or slush. (2) A popular alternative for glaze. A thin sheet of ice, relatively dark in appearance, may form when light rain or drizzle falls on a road surface that is at a temperature below 0 °C or, alternatively, when water already on the road surface subsequently freezes when the temperature thereof falls below freezing point. It may also be formed when supercooled fog droplets are intercepted by buildings, fences and vegetation.",
        62: "Occurs when dry and low-lying land is submerged by seawater.",
        63: "Extreme cold and low temperatures.",
        64: "Widespread and usually fast-moving windstorms associated with convection/convective storm. Derechos include downburst and straight-line winds. The damage from derechos is often confused with the damage from tornadoes.",
        65: "An extended period of unusually low precipitation that produces a shortage of water for people, animals and plants. Drought is different from most other hazards in that it develops slowly, sometimes even over years, and its onset is generally difficult to detect.",
        66: "Strong winds carry particles of sand aloft, but generally confined to less than 50 feet (15 m), especially common in arid and semi-arid environments. A dust storm is also characterised by strong winds but carries smaller particles of dust rather than sand over an extensive area.",
        67: "Floating ice in rivers or icebergs in the open sea.",
        68: "A general term for the overflow of water from a stream channel onto normally dry land in the floodplain (riverine flooding), higher-than normal levels along the coast and in lakes or reservoirs (coastal flooding) as well as ponding of water at or near the point where the rain fell (flash floods).",
        69: "A suspension of very small, usually microscopic water droplets in the air, reducing visibility at the Earth’s surface.",
        70: "Solid precipitation in the form of irregular pellets or balls of ice more than 5 mm in diameter.",
        71: "A general term for temperature variations above (extreme heat).",
        72: "A high-voltage, visible electrical discharge produced by a thunderstorm and followed by the sound of thunder.",
        73: "Pollens that can cause human allergies are those of anemophilous plants (pollen is dispersed by air currents.) Such plants produce large quantities of lightweight pollen (because wind dispersal is random and the likelihood of one pollen grain landing on another flower is small), which can be carried for great distances and are easily inhaled by humans.",
        74: "Rainfall greater than or equal to 50 mm in past 24 hours. Note: Precise threshold is according to each local standard.",
        75: "A low-pressure system in winter months with significant accumulations of snow, freezing rain, sleet or ice. A blizzard is a severe snowstorm with winds exceeding 35 mph (56 km/h) for three or more hours, producing reduced visibility (less than .25 mile (400 m).",
        76: "Snowfall greater than or equal to 50 mm in past 24 hours. Note: Precise threshold is according to each local standard.",
        77: "Meteorological event generating winds equal or higher than 10 on the Beaufort scale.",
        78: "Gradual warning causing ground ice to degrade, potentially leading the soil surface to collapse.",
        79: "A violently rotating column of air that reaches the ground or open water (waterspout).",
        80: "A tropical cyclone originates over tropical or subtropical waters. It is characterised by a warm-core, non-frontal synoptic-scale cyclone with a low-pressure centre, spiral rain bands and strong winds. Depending on their location, tropical cyclones are referred to as hurricanes (Atlantic, Northeast Pacific), typhoons (Northwest Pacific), or cyclones (South Pacific and Indian Ocean). With a minimum wind speed of 119 km/h (or 74 miles/h) a tropical storm in the Atlantic or Northeast Pacific is called a hurricane.",
        81: "Frost is the consequence of radiative cooling resulting in the formation of thin ice crystals on the ground or other surfaces in the form of needles, feathers, scales, or fans. Frost occurs when the temperature of surfaces is below freezing and water vapor from humid air forms solid deposits on the cold surface. Freeze occurs when the air temperature is at (32 °F / 0 °C) or below over a widespread area for a climatologically significant period of time. Use of the term is usually restricted to advective situations or to occasions when wind or other conditions prevent frost. Frost and freeze are particularly damaging during the crop growing season.",
        82: "A tropical cyclone originates over tropical or subtropical waters. It is characterised by a warm-core, non-frontal synoptic-scale cyclone with a low-pressure centre, spiral rain bands and strong winds. Depending on their location, tropical cyclones are referred to as hurricanes (Atlantic, Northeast Pacific), typhoons (Northwest Pacific), or cyclones (South Pacific and Indian Ocean). With a minimum wind speed of 119 km/h (or 74 miles/h) a tropical storm in the Atlantic or Northeast Pacific is called a hurricane.",
        83: "Incident at a dam potentially leading to the uncontrolled release of the dam content.",
        84: "Incident at a dike potentially leading to the uncontrolled release of water.",
        85: "Activity to render safe all types of ordnance, including explosive, chemical and biological. It covers land and underwater location, identification, render-safe, and recovery (or disposal) of ordnance.",
        86: "Incident at an industrial site affecting the surrounding area.",
        87: "Any of the dangers peculiar to the winning and working of coal and minerals. These include collapse of ground, explosion of released gas, inundation by water, spontaneous combustion, inhalation of dust and poisonous gases, etc.",
        88: "Unexpected presence of bomb or ammunition.",
        89: "A march or gathering of people taking part in to show their opposition to something or their support for something.",
        90: "An unexpected uncontrolled release of substances that have the potential to harm a person or the environment upon contact.",
        91: "Emergency situation that requires immediate intervention to save the life of the persons concerned.",
        92: "Planned happening which may generate significant disruption in road traffic or transport.",
        93: "Unaccounted person whose health status (alive/dead) cannot be confirmed.",
        94: "Intentional use of explosive materials aiming at killing or damaging the health of humans, animals, plants, or the environment.",
        95: "Announcement of a potentially dangerous situation or event to the public impacting their safety.",
        96: "Presence of an unidentified flying object which may present a risk or potential risk to the health of humans, animals, plants, or the environment.",
        97: "Presence of an unidentified animal which may present a risk or a potential risk to the health of humans, animals, plants, or the environment.",
        98: "Intentional use of dangerous chemical materials aiming at killing or damaging the health of humans, animals, plants, or the environment.",
        99: "Paramilitary armed forces carrying violent actions.",
        100: "Airplane or other vehicle under the control of hijackers.",
        101: "Dangerous use of firearm(s) or weapons in a populated area.",
        102: "Military armed forces carrying violent actions.",
        103: "Terrorist action aiming at generating a high number of victims or major material damage.",
        104: "Aircraft crash.",
        105: "Structural failure of a bridge resulting in its partial or total destruction.",
        106: "Accident occurrence associated with and related to the conveyance of dangerous goods by air, road, inland waterways and sea, which results in fatal or serious injury to a person or major damage to property or environment.",
        107: "Ship accident on an inland waterway.",
        108: "Sinking ship or any other event occurring at sea which may present of security or safety risk.",
        109: "Leak of oil or pollutant from a ship or other transportation mean resulting in pollution.",
        110: "Announcement of road traffic disruption.",
        111: "Accident occurring on a railway and involving train(s) and/or other vehicles.",
        112: "Car crash or railway accident occurring in a tunnel.",
        113: "Test alert message for end-to-end testing.",
    },
    undefined= "Undefined hazard definition. (Code: %d)",
)
