from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a2_country_region_name = QzssDcrDefinition(
    {
        0: "Afghanistan",
        1: "Albania",
        2: "Antarctica",
        3: "Algeria",
        4: "American Samoa",
        5: "Andorra",
        6: "Angola",
        7: "Antigua and Barbuda",
        8: "Azerbaijan",
        9: "Argentina",
        10: "Australia",
        11: "Austria",
        12: "The Bahamas",
        13: "Bahrain",
        14: "Bangladesh",
        15: "Armenia",
        16: "Barbados",
        17: "Belgium",
        18: "Bermuda",
        19: "Bhutan",
        20: "Plurinational State of Bolivia ",
        21: "Bosnia and Herzegovina",
        22: "Botswana",
        23: "Bouvet Island",
        24: "Brazil",
        25: "Belize",
        26: "The British Indian Ocean Territory",
        27: "Solomon Islands",
        28: "British Virgin Islands",
        29: "Brunei Darussalam",
        30: "Bulgaria",
        31: "Myanmar",
        32: "Burundi",
        33: "Belarus",
        34: "Cambodia",
        35: "Cameroon",
        36: "Canada",
        37: "Cabo Verde",
        38: "The Cayman Islands",
        39: "The Central African Republic",
        40: "Sri Lanka",
        41: "Chad",
        42: "Chile",
        43: "China",
        44: "Taiwan",
        45: "Christmas Island",
        46: "The Cocos (Keeling) Islands",
        47: "Colombia",
        48: "The Comoros the",
        49: "Mayotte",
        50: "The Congo",
        51: "The Democratic Republic of the Congo",
        52: "The Cook Islands",
        53: "Costa Rica",
        54: "Croatia",
        55: "Cuba",
        56: "Cyprus",
        57: "Czechia",
        58: "Benin",
        59: "Denmark",
        60: "Dominica",
        61: "The Dominican Republic",
        62: "Ecuador",
        63: "El Salvador",
        64: "Equatorial Guinea",
        65: "Ethiopia",
        66: "Eritrea",
        67: "Estonia",
        68: "The Faroe Islands",
        69: "The Falkland Islands [Malvinas]",
        70: "South Georgia and the South Sandwich Islands",
        71: "Fiji",
        72: "Finland",
        73: "Åland Islands",
        74: "France",
        75: "French Guiana",
        76: "French Polynesia",
        77: "The French Southern Territories",
        78: "Djibouti",
        79: "Gabon",
        80: "Georgia",
        81: "The Gambia",
        82: "State of Palestine",
        83: "Germany",
        84: "Ghana",
        85: "Gibraltar",
        86: "Kiribati",
        87: "Greece",
        88: "Greenland",
        89: "Grenada",
        90: "Guadeloupe",
        91: "Guam",
        92: "Guatemala",
        93: "Guinea",
        94: "Guyana",
        95: "Haiti",
        96: "Heard Island and McDonald Islands",
        97: "The Holy See",
        98: "Honduras",
        99: "Hong Kong",
        100: "Hungary",
        101: "Iceland",
        102: "India",
        103: "Indonesia",
        104: "Islamic Republic of Iran",
        105: "Iraq",
        106: "Ireland",
        107: "Israel",
        108: "Italy",
        109: "Côte d'Ivoire",
        110: "Jamaica",
        111: "Japan",
        112: "Kazakhstan",
        113: "Jordan",
        114: "Kenya",
        115: "The Democratic People's Republic of Korea",
        116: "The Republic of Korea",
        117: "Kuwait",
        118: "Kyrgyzstan",
        119: "The Lao People's Democratic Republic",
        120: "Lebanon",
        121: "Lesotho",
        122: "Latvia",
        123: "Liberia",
        124: "Libya",
        125: "Liechtenstein",
        126: "Lithuania",
        127: "Luxembourg",
        128: "Macao",
        129: "Madagascar",
        130: "Malawi",
        131: "Malaysia",
        132: "Maldives",
        133: "Mali",
        134: "Malta",
        135: "Martinique",
        136: "Mauritania",
        137: "Mauritius",
        138: "Mexico",
        139: "Monaco",
        140: "Mongolia",
        141: "The Republic of Moldova",
        142: "Montenegro",
        143: "Montserrat",
        144: "Morocco",
        145: "Mozambique",
        146: "Oman",
        147: "Namibia",
        148: "Nauru",
        149: "Nepal",
        150: "The Netherlands",
        151: "Curaçao",
        152: "Aruba",
        153: "Sint Maarten (Dutch part)",
        154: "Bonaire, Sint Eustatius and Saba",
        155: "New Caledonia",
        156: "Vanuatu",
        157: "New Zealand",
        158: "Nicaragua",
        159: "The Niger",
        160: "Nigeria",
        161: "Niue",
        162: "Norfolk Island",
        163: "Norway",
        164: "The Northern Mariana Islands",
        165: "The United States Minor Outlying Islands",
        166: "Federated States of Micronesia",
        167: "The Marshall Islands",
        168: "Palau",
        169: "Pakistan",
        170: "Panama",
        171: "Papua New Guinea",
        172: "Paraguay",
        173: "Peru",
        174: "The Philippines",
        175: "Pitcairn",
        176: "Poland",
        177: "Portugal",
        178: "Guinea-Bissau",
        179: "Timor-Leste",
        180: "Puerto Rico",
        181: "Qatar",
        182: "Réunion",
        183: "Romania",
        184: "The Russian Federation",
        185: "Rwanda",
        186: "Saint Barthélemy",
        187: "Saint Helena, Ascension and Tristan da Cunha",
        188: "Saint Kitts and Nevis",
        189: "Anguilla",
        190: "Saint Lucia",
        191: "Saint Martin (French part)",
        192: "Saint Pierre and Miquelon",
        193: "Saint Vincent and the Grenadines",
        194: "San Marino",
        195: "Sao Tome and Principe",
        196: "Saudi Arabia",
        197: "Senegal",
        198: "Serbia",
        199: "Seychelles",
        200: "Sierra Leone",
        201: "Singapore",
        202: "Slovakia",
        203: "Viet Nam",
        204: "Slovenia",
        205: "Somalia",
        206: "South Africa",
        207: "Zimbabwe",
        208: "Spain",
        209: "South Sudan",
        210: "The Sudan",
        211: "Western Sahara*",
        212: "Suriname",
        213: "Svalbard and Jan Mayen",
        214: "Eswatini",
        215: "Sweden",
        216: "Switzerland",
        217: "The Syrian Arab Republic",
        218: "Tajikistan",
        219: "Thailand",
        220: "Togo",
        221: "Tokelau",
        222: "Tonga",
        223: "Trinidad and Tobago",
        224: "The United Arab Emirates",
        225: "Tunisia",
        226: "Turkey",
        227: "Turkmenistan",
        228: "The Turks and Caicos Islands",
        229: "Tuvalu",
        230: "Uganda",
        231: "Ukraine",
        232: "North Macedonia",
        233: "Egypt",
        234: "The United Kingdom of Great Britain and Northern Ireland",
        235: "Guernsey",
        236: "Jersey",
        237: "Isle of Man",
        238: "Tanzania, the United Republic of",
        239: "The United States of America",
        240: "Virgin Islands (U.S.)",
        241: "Burkina Faso",
        242: "Uruguay",
        243: "Uzbekistan",
        244: "Bolivarian Republic of Venezuela",
        245: "Wallis and Futuna",
        246: "Samoa",
        247: "Yemen",
        248: "Zambia",
        500: "EU Organisations",
        501: "UN Organisations",
        502: "International",
    },
    undefined = "Undefined Country/Region (Code: %d)"
)
