from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_a11_japanese_library_en = QzssDcrDefinition(
    {
        0: "",
        1: "Take the best immediate action to save your life.",
        126: "This is a test message for DCX.",
        127: "Take the best immediate action to save your life.",
        128: "Missile launched, missile launched. It is believed that a missile was launched. Please take shelter inside buildings or underground.",
        129: "Missile passed, missile passed. It is believed that the previous missile has passed over the area. The call for evacuation will be canceled. If you find any suspicious object, please stay away from it and inform the police or the fire department immediately.",
        130: "It is believed that the previous missile has dropped in the sea. The call for evacuation will be canceled. If you find any suspicious object, please stay away from it and inform the police or the fire department immediately.",
        131: "It is believed that the previous missile will not come to Japan. The call for evacuation will be canceled.",
        132: "Take shelter immediately, take shelter immediately. Please take shelter inside buildings or underground. It is believed that a missile will drop around this area. Please take shelter immediately.",
        133: "The previous missile has been intercepted and destroyed. There is a possibility of pieces of the destroyed missile dropping. We will keep you informed. Please stay indoors for shelter.",
        134: "Missile dropped, missile dropped. It is believed that a missile has dropped around this area. We will keep you informed. Please stay indoors for shelter.",
        135: "It is believed that the previous missile will not drop in Japan. The call for evacuation will be canceled.",
        136: "This is a test message for J-Alert.",
        255: "Take immediate action to save your life.",
        256: "Stay.",
        257: "Stay. Under/inside a solid structure.",
        258: "Stay. 3rd floor or higher.",
        259: "Stay. Underground.",
        260: "Stay. Mountain.",
        261: "Stay. Water area.",
        262: "Stay. Building where chemicals are handled, such as a factory.",
        263: "Stay. Cliffs and areas at risk of collapse.",
        512: "Move to/toward",
        513: "Move to/toward Under/inside a solid structure.",
        514: "Move to/toward 3rd floor or higher.",
        515: "Move to/toward Underground.",
        516: "Move to/toward Mountain.",
        517: "Move to/toward Water area.",
        518: "Move to/toward Building where chemicals are handled, such as a factory.",
        519: "Move to/toward Cliffs and areas at risk of collapse.",
        768: "Keep away from",
        769: "Keep away from Under/inside a solid structure.",
        770: "Keep away from 3rd floor or higher.",
        771: "Keep away from Underground.",
        772: "Keep away from Mountain.",
        773: "Keep away from Water area.",
        774: "Keep away from Building where chemicals are handled, such as a factory.",
        775: "Keep away from Cliffs and areas at risk of collapse.",
    },
    undefined = "Undefined guidance to react instruction in the japanese library. (Code: %d)"
)


qzss_dcx_camf_a11_japanese_library_ja = QzssDcrDefinition(
    {
        0: "",
        1: "直ちに命を守るための最善の行動を。",
        126: "これは、DCX のテストです。",
        127: "直ちに命を守るための最善の行動を。",
        128: "ミサイル発射。ミサイル発射。ミサイルが発射されたものとみられます。建物の中、又は地下に避難して下さい。",
        129: "ミサイル通過。ミサイル通過。先程のミサイルは通過したものとみられます。避難の呼びかけを解除します。不審なものには決して近寄らず直ちに警察や消防などに連絡して下さい。",
        130: "先程のミサイルは、海に落下したものとみられます。避難の呼びかけを解除します。不審なものには決して近寄らず直ちに警察や消防などに連絡して下さい。",
        131: "先程のミサイルは、我が国には飛来しないものとみられます。避難の呼びかけを解除します。",
        132: "直ちに避難。直ちに避難。直ちに建物の中、又は地下に避難して下さい。ミサイルが、周辺に落下するものとみられます。直ちに避難して下さい。",
        133: "先程のミサイルは、迎撃により破壊されました。ミサイルの破片の落下の可能性があります。続報を伝達しますので、引き続き屋内に避難して下さい。",
        134: "ミサイル落下。ミサイル落下。ミサイルが、周辺に落下したものとみられます。続報を伝達しますので、引き続き屋内に避難して下さい。",
        135: "先程のミサイルは、我が国には落下しないものとみられます。避難の呼びかけを解除します。",
        136: "これは、Jアラートのテストです。",
        255: "直ちに命を守るための最善の行動を。",
        256: "留まれ。",
        257: "留まれ。頑丈なものの下/中。",
        258: "留まれ。3階以上。",
        259: "留まれ。地下。",
        260: "留まれ。山。",
        261: "留まれ。水場。",
        262: "留まれ。工場等化学系を取扱う建物。",
        263: "留まれ。崖等崩れやすい場所。",
        512: "向かえ。",
        513: "向かえ。頑丈なものの下/中。",
        514: "向かえ。3階以上。",
        515: "向かえ。地下。",
        516: "向かえ。山。",
        517: "向かえ。水場。",
        518: "向かえ。工場等化学系を取扱う建物。",
        519: "向かえ。崖等崩れやすい場所。",
        768: "離れろ。",
        769: "離れろ。頑丈なものの下/中。",
        770: "離れろ。3階以上。",
        771: "離れろ。地下。",
        772: "離れろ。山。",
        773: "離れろ。水場。",
        774: "離れろ。工場等化学系を取扱う建物。",
        775: "離れろ。崖等崩れやすい場所。",
    },
    undefined = "避難情報(コード番号：%d)"
)
