from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcx_camf_c10_guidance_library_for_second_ellipse_code = QzssDcrDefinition(
    {
        0: "IC-C-01",
        1: "IC-C-02",
        2: "IC-C-03",
        3: "IC-C-04",
        4: "IC-C-05",
        5: "IC-C-06",
        6: "IC-C-07",
        7: "IC-C-08",
        8: "IC-C-09",
        9: "IC-C-10",
        10: "IC-C-11",
        11: "IC-C-12",
        12: "IC-C-13",
        13: "IC-C-14",
        14: "IC-C-15",
        15: "IC-C-16",
        16: "IC-C-17",
        30: "IC-C-31",
        31: "IC-C-32",
    },
    undefined='IC-C-UNDEFINED (Code: %d)'
)

qzss_dcx_camf_c10_guidance_library_for_second_ellipse = QzssDcrDefinition(
    {
        0: "",
        1: "Prepare for evacuation. Take only the essentials with you, especially ID cards, passport, credit cards and cash. Evacuate only after the instruction of the emergency authorities.",
        2: "Prepare emergency food and relief material: Check and restock your equipment and supplies of water, food, medicine, cash and batteries.",
        3: "Be prepared to protect yourself and your property. Flooding of properties and transport networks is expected. Disruption to power, communications and water supplies are possible. Evacuation may be required. Dangerous driving conditions due to reduced visibility and aquaplaning.",
        4: "Have iodine tablets ready. DO NOT take the iodine tablets now. If this becomes necessary, we will inform you in good time.",
        5: "Keep your smartphone charged to be able to receive further instructions and information.",
        6: "Avoid using lifts.",
        7: "Avoid the danger area.",
        8: "Avoid driving.",
        9: "Rescue operation under process by security forces and emergency services. Avoid moving to facilitate security and emergency actions.",
        10: "Check with the weather services and local authorities for additional information.",
        11: "Find out the location of the information points set up by the authorities on official channels (radio, internet, TV, social networks...).",
        12: "Sensitive or vulnerable people should not go out unless they must.",
        13: "Protect the most vulnerable and hear from your loved ones. Be aware of their special needs and support, as required. If you notice distressed or vulnerable persons, contact the emergency services. Provide first aid if necessary but do not put yourself in any danger.",
        14: "Pay attention to announcements made by the police, fire brigade and by officials.",
        15: "Stay aware, keep listening to official instructions broadcast on the radio, television, websites and social networks pages.",
        16: "Only make phone calls in serious emergencies to avoid overloading the mobile network.",
        30: "This is only a test. You do not have to take any action or to adopt any particular sheltering behaviour.",
        31: "Conditions have improved and are no longer expected to meet alert criteria.",
    },
    undefined='Undefined instruction for second ellipse. (Code: %d)'
)
